@@ -7,14 +7,14 @@ __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-devices"
 __date__ = "23-07-2020"
-__version__ = "0.1.0"
+__version__ = "0.2.1"
 
 import numpy as np
 
 from PyQt5 import QtCore, QtGui
 from PyQt5 import QtWidgets as QtWid
 
-from dvg_utils.dvg_pyqt_controls import (
+from dvg_pyqt_controls import (
     create_Toggle_button,
     create_tiny_error_LED,
     SS_TEXTBOX_ERRORS,
